@@ -1,5 +1,3 @@
-context("test-blr-gains-table.R")
-
 model <- glm(
   honcomp ~ female + read + science, data = hsb2,
   family = binomial(link = "logit")
@@ -12,7 +10,7 @@ test_that("output from blr_gains_table is as expected", {
   accu     <- round(mean(gtable$gains_table$accuracy), 2)
   actual   <- c(sens, spec, accu)
   expected <- c(80.94, 54.35, 61.40)
-  expect_equivalent(actual, expected)
+  expect_equal(actual, expected)
 })
 
 
